**Yet Another Form WIdget Library**.

YAFOWIL offers html-form creation and modification at runtime. Its light-weight
and provides an extensible, reusable set of blueprints to build flexible forms.

YAFOWIL is independent from any web-framework, but easy to use in your
web-framework.

It's all just about rendering widgets and extracting the data returned from the
browser per widget. It does not fight with storage.

YAFOWIL vary from most other HTML form packages: Its all just configuration. No
subclassing needed any more; no specific schema-framework is necessary.

Yafowil provides a factory where you can fetch your widgets instances from.
Or you register your own.

Detailed Documentation
======================

If you're interested to dig deeper: The `detailed YAFOWIL documentation
<http://yafowil.info>`_ is available. Read it and learn how to
create your example application with YAFOWIL forms in 15 minutes.

Source Code
===========

The sources are in a GIT DVCS with its main branches at
`github <http://github.com/bluedynamics/yafowil>`_.

We'd be happy to see many forks and pull-requests to make YAFOWIL even better.

Contributors
============

- Jens W. Klein <jk@kleinundpartner.at>

- Robert Niederrreiter <rnix@squarewave.at>

- Peter Holzer <peter.holzer@agitator.com>

- Attila Olah

- Christian Scholz aka MrTopf (initial discussion)
